skills.level.display

# XMLRésuméLibrary: User Guide

skills.format | XSL Parameter Reference | subjects.format

## Name

skills.level.display — Determines whether or not skill level attributes are visible in formatted output

## Applies To

This parameter controls the formatting of the `level` attribute of `skill` elements in all output formats.

## Possible Values

Possible values include `1` (display the attribute) or `0` (suppress the attribute).

`1` (true)

  `level` attributes of `skill`s are displayed after all of the rest of the content of the skill. The level is displayed surrounded by `skills.level.start` and `skills.level.end` (parenthesis, by default).

`0` (false)

  `level` attributes contained in `skill`s are suppressed; they are treated as if the didn't exist for formatting purposes.

skills.format | XSL Parameter Reference | subjects.format